==> webgui_7.6.27.orig.tar.gz: WebGUI/lib/WebGUI/i18n/English/Asset_MessageBoard.pm <==
package WebGUI::i18n::English::Asset_MessageBoard;
use strict;

our $I18N = {
	'visitor cache timeout' => {
		message => q|Visitor Cache Timeout|,
		lastUpdated => 0
		},

	'visitor cache timeout help' => {
		message => q|Since all visitors will see this asset the same way, we can cache it to increase performance. How long should we cache it?|,
		lastUpdated => 1146454744
		},

	'forum.add.url' => {
		message => q|A url that will add a forum to this message board.|,
		lastUpdated => 1149632734,
	},

	'forum.add.label' => {
		message => q|The default label for forum.add.url.|,
		lastUpdated => 1149632734,
	},

	'title.label' => {
		message => q|The default label for the title column.|,
		lastUpdated => 1149632734,
	},

	'views.label' => {
		message => q|The default label for the views column.|,
		lastUpdated => 1149632734,
	},

	'rating.label' => {
		message => q|The default label for the ratings column.|,
		lastUpdated => 1149632734,
	},

	'threads.label' => {
		message => q|The default label for the threads column.|,
		lastUpdated => 1149632734,
	},

	'replies.label' => {
		message => q|The default label for the replies column.|,
		lastUpdated => 1149632734,
	},

	'lastpost.label' => {
		message => q|The default label for the last post column.|,
		lastUpdated => 1149632734,
	},

	'forum_loop' => {
		message => q|A loop containing the data for each of the forums contained in this message board.|,
		lastUpdated => 1149632734,
	},

	'forum.controls' => {
		message => q|The editing controls for this forum.|,
		lastUpdated => 1149632734,
	},

	'forum.count' => {
		message => q|An integer displaying the forum count as it goes through the loop.|,
		lastUpdated => 1149632734,
	},

	'forum.title' => {
		message => q|The title of this forum.|,
		lastUpdated => 1149632734,
	},

	'forum.description' => {
		message => q|The description of this forum.|,
		lastUpdated => 1149632734,
	},

	'forum.replies' => {
		message => q|The number of replies all the threads in this forum have received.|,
		lastUpdated => 1149632734,
	},

	'forum.rating' => {
		message => q|The average rating of all the posts in the forum.|,
		lastUpdated => 1149632734,
	},

	'forum.views' => {
		message => q|The total number of views of all the posts in the forum.|,
		lastUpdated => 1149632734,
	},

	'forum.threads' => {
		message => q|The total number of threads in this forum.|,
		lastUpdated => 1149632734,
	},

	'forum.url' => {
		message => q|The url to view this forum.|,
		lastUpdated => 1149632734,
	},

	'forum.lastpost.user.hasread' => {
		message => q|A boolean indicating whether the user has read the last post in the forum.|,
		lastUpdated => 1149632734,
	},

	'forum.lastpost.url' => {
		message => q|The url to view the last post in this forum.|,
		lastUpdated => 1149632734,
	},

	'forum.lastpost.date' => {
		message => q|The human readable date of the last post in this forum.|,
		lastUpdated => 1149632734,
	},

	'forum.lastpost.time' => {
		message => q|The human readable time of the last post in this forum.|,
		lastUpdated => 1149632734,
	},

	'forum.lastpost.epoch' => {
		message => q|The epoch date of the last post in this forum.|,
		lastUpdated => 1149632734,
	},

	'forum.lastpost.subject' => {
		message => q|The subject of the last post in this forum.|,
		lastUpdated => 1149632734,
	},

	'forum.lastpost.user.id' => {
		message => q|The userid of the last poster.|,
		lastUpdated => 1149632734,
	},

	'forum.lastpost.user.name' => {
		message => q|The username of the last poster.|,
		lastUpdated => 1149632734,
	},

	'forum.lastpost.user.alias' => {
		message => q|The current alias of the last poster.|,
		lastUpdated => 1149632734,
	},

	'forum.lastpost.user.profile' => {
		message => q|The url to the last poster's profile.|,
		lastUpdated => 1149632734,
	},

	'forum.lastpost.user.isVisitor' => {
		message => q|A conditional indicating whether the last poster was a visitor.|,
		lastUpdated => 1149632734,
	},

	'forum.user.canView' => {
		message => q|A conditional indicating whether the user can view this forum.|,
		lastUpdated => 1149632734,
	},

	'forum.user.canPost' => {
		message => q|A conditional indicating whether the user can post to this forum.|,
		lastUpdated => 1149632734,
	},

	'default.listing' => {
		message => q|A full forum rendered using the forum template.|,
		lastUpdated => 1149632734,
	},

	'areMultipleForums' => {
		message => q|A conditional indicating whether there is more than one forum.|,
		lastUpdated => 1149632734,
	},

	'74' => {
		message => q|<p>The following is the list of template variables available in message board templates:</p>
|,
		lastUpdated => 1149632767
	},

	'6' => {
		message => q|Edit Message Board|,
		lastUpdated => 1031514049
	},

	'75' => {
		message => q|Add a forum|,
		lastUpdated => 1066038194
	},

	'assetName' => {
		message => q|Message Board|,
		lastUpdated => 1128831826
	},

	'73' => {
		message => q|Message Board Template|,
		lastUpdated => 1066584179
	},

	'73 description' => {
		message => q|Choose a template to display your message board|,
		lastUpdated => 1119411673
	},

	'76' => {
		message => q|Are you certain you wish to delete this forum and all the posts it contains?|,
		lastUpdated => 1066055963
	},

	'title' => {
		message => q|Title|,
		lastUpdated => 1109806115,
	},

	'views' => {
		message => q|Views|,
		lastUpdated => 1109806115,
	},

	'rating' => {
		message => q|Rating|,
		lastUpdated => 1109806115,
	},

	'threads' => {
		message => q|Threads|,
		lastUpdated => 1109806115,
	},

	'replies' => {
		message => q|Replies|,
		lastUpdated => 1109806115,
	},

	'lastpost' => {
		message => q|Last Post|,
		lastUpdated => 1109806115,
	},

	'message board asset template variables title' => {
		message => q|Message Board Asset Template Variables|,
		lastUpdated => 1164841146
	},

	'message board asset template variables body' => {
		message => q|Every asset provides a set of variables to most of its
templates based on the internal asset properties.  Some of these variables may
be useful, others may not.|,
		lastUpdated => 1164841201
	},

	'visitorCacheTimeout' => {
		message => q|The amount of time this article will be cached for the Visitor user.|,
		lastUpdated => 1164841027
	},

	'templateId' => {
		message => q|The Id of the template used to display this Asset.|,
		lastUpdated => 1164841027
	},

};

1;

==> webgui_7.10.29.orig.tar.gz: WebGUI/lib/WebGUI/i18n/English/Asset_MessageBoard.pm <==
package WebGUI::i18n::English::Asset_MessageBoard;
use strict;

our $I18N = {
	'visitor cache timeout' => {
		message => q|Visitor Cache Timeout|,
		lastUpdated => 0
		},

	'visitor cache timeout help' => {
		message => q|Since all visitors will see this asset the same way, we can cache it to increase performance. How long should we cache it?|,
		lastUpdated => 1146454744
		},

	'forum.add.url' => {
		message => q|A url that will add a forum to this message board.|,
		lastUpdated => 1149632734,
	},

	'forum.add.label' => {
		message => q|The default label for forum.add.url.|,
		lastUpdated => 1149632734,
	},

	'title.label' => {
		message => q|The default label for the title column.|,
		lastUpdated => 1149632734,
	},

	'views.label' => {
		message => q|The default label for the views column.|,
		lastUpdated => 1149632734,
	},

	'rating.label' => {
		message => q|The default label for the ratings column.|,
		lastUpdated => 1149632734,
	},

	'threads.label' => {
		message => q|The default label for the threads column.|,
		lastUpdated => 1149632734,
	},

	'replies.label' => {
		message => q|The default label for the replies column.|,
		lastUpdated => 1149632734,
	},

	'lastpost.label' => {
		message => q|The default label for the last post column.|,
		lastUpdated => 1149632734,
	},

	'forum_loop' => {
		message => q|A loop containing the data for each of the forums contained in this message board.|,
		lastUpdated => 1149632734,
	},

	'forum.controls' => {
		message => q|The editing controls for this forum.|,
		lastUpdated => 1149632734,
	},

	'forum.count' => {
		message => q|An integer displaying the forum count as it goes through the loop.|,
		lastUpdated => 1149632734,
	},

	'forum.title' => {
		message => q|The title of this forum.|,
		lastUpdated => 1149632734,
	},

	'forum.description' => {
		message => q|The description of this forum.|,
		lastUpdated => 1149632734,
	},

	'forum.replies' => {
		message => q|The number of replies all the threads in this forum have received.|,
		lastUpdated => 1149632734,
	},

	'forum.rating' => {
		message => q|The average rating of all the posts in the forum.|,
		lastUpdated => 1149632734,
	},

	'forum.views' => {
		message => q|The total number of views of all the posts in the forum.|,
		lastUpdated => 1149632734,
	},

	'forum.threads' => {
		message => q|The total number of threads in this forum.  This does not include those that have been archived.|,
		lastUpdated => 1263239637,
	},

	'forum.url' => {
		message => q|The url to view this forum.|,
		lastUpdated => 1149632734,
	},

	'forum.lastpost.user.hasread' => {
		message => q|A boolean indicating whether the user has read the last post in the forum.|,
		lastUpdated => 1149632734,
	},

	'forum.lastpost.url' => {
		message => q|The url to view the last post in this forum.|,
		lastUpdated => 1149632734,
	},

	'forum.lastpost.date' => {
		message => q|The human readable date of the last post in this forum.|,
		lastUpdated => 1149632734,
	},

	'forum.lastpost.time' => {
		message => q|The human readable time of the last post in this forum.|,
		lastUpdated => 1149632734,
	},

	'forum.lastpost.epoch' => {
		message => q|The epoch date of the last post in this forum.|,
		lastUpdated => 1149632734,
	},

	'forum.lastpost.subject' => {
		message => q|The subject of the last post in this forum.|,
		lastUpdated => 1149632734,
	},

	'forum.lastpost.user.id' => {
		message => q|The userid of the last poster.|,
		lastUpdated => 1149632734,
	},

	'forum.lastpost.user.name' => {
		message => q|The username of the last poster.|,
		lastUpdated => 1149632734,
	},

	'forum.lastpost.user.alias' => {
		message => q|The current alias of the last poster.|,
		lastUpdated => 1149632734,
	},

	'forum.lastpost.user.profile' => {
		message => q|The url to the last poster's profile.|,
		lastUpdated => 1149632734,
	},

	'forum.lastpost.user.isVisitor' => {
		message => q|A conditional indicating whether the last poster was a visitor.|,
		lastUpdated => 1149632734,
	},

	'forum.user.canView' => {
		message => q|A conditional indicating whether the user can view this forum.|,
		lastUpdated => 1149632734,
	},

	'forum.user.canPost' => {
		message => q|A conditional indicating whether the user can post to this forum.|,
		lastUpdated => 1149632734,
	},

	'default.listing' => {
		message => q|A full forum rendered using the forum template.|,
		lastUpdated => 1149632734,
	},

	'areMultipleForums' => {
		message => q|A conditional indicating whether there is more than one forum.|,
		lastUpdated => 1149632734,
	},

	'74' => {
		message => q|<p>The following is the list of template variables available in message board templates:</p>
|,
		lastUpdated => 1149632767
	},

	'6' => {
		message => q|Edit Message Board|,
		lastUpdated => 1031514049
	},

	'75' => {
		message => q|Add a forum|,
		lastUpdated => 1066038194
	},

	'assetName' => {
		message => q|Message Board|,
		lastUpdated => 1128831826
	},

	'73' => {
		message => q|Message Board Template|,
		lastUpdated => 1066584179
	},

	'73 description' => {
		message => q|Choose a template to display your message board|,
		lastUpdated => 1119411673
	},

	'76' => {
		message => q|Are you certain you wish to delete this forum and all the posts it contains?|,
		lastUpdated => 1066055963
	},

	'title' => {
		message => q|Title|,
		lastUpdated => 1109806115,
	},

	'views' => {
		message => q|Views|,
		lastUpdated => 1109806115,
	},

	'rating' => {
		message => q|Rating|,
		lastUpdated => 1109806115,
	},

	'threads' => {
		message => q|Threads|,
		lastUpdated => 1109806115,
	},

	'replies' => {
		message => q|Replies|,
		lastUpdated => 1109806115,
	},

	'lastpost' => {
		message => q|Last Post|,
		lastUpdated => 1109806115,
	},

	'message board asset template variables title' => {
		message => q|Message Board Asset Template Variables|,
		lastUpdated => 1164841146
	},

	'message board asset template variables body' => {
		message => q|Every asset provides a set of variables to most of its
templates based on the internal asset properties.  Some of these variables may
be useful, others may not.|,
		lastUpdated => 1164841201
	},

	'visitorCacheTimeout' => {
		message => q|The amount of time this article will be cached for the Visitor user.|,
		lastUpdated => 1164841027
	},

	'templateId' => {
		message => q|The Id of the template used to display this Asset.|,
		lastUpdated => 1164841027
	},

};

1;
